from typing import Mapping
from pulumi import StackReference as _stack, Output
from pydantic.dataclasses import dataclass, ConfigDict

TagType = Mapping[str | Output[str], str | Output[str]]


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class _StackRegistry:
    data: Mapping[str, _stack]

    def register(self, stack_name: str, stack_object: _stack) -> None:
        self.data[stack_name] = stack_object

    def get(self, stack_name) -> _stack:
        return self.data.get(stack_name)


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class _GlobalTags:
    tags: TagType

    def register(self, tags: TagType) -> None:
        self.tags = self.tags | tags

    def get(self):
        return self.tags


GlobalTags = _GlobalTags({})
StackRegistry = _StackRegistry(data={})
