from typing import List, Mapping
from pulumi import Output
import pulumi_aws
from pulumi_aws.ecs import ServiceNetworkConfigurationArgs

def create_ecs_service(resource_name:str, cluster:pulumi_aws.ecs.Cluster, task_definition:pulumi_aws.ecs.TaskDefinition, subnet_ids: Mapping[str, str], target_group:pulumi_aws.lb.TargetGroup, security_groups:List[Output[pulumi_aws.ec2.SecurityGroup]]):
    # Create an ECS service
    service = pulumi_aws.ecs.Service(f"{resource_name}-service",
        cluster=cluster.arn,
        desired_count=2,
        launch_type="FARGATE",
        task_definition=task_definition.arn,
        network_configuration={
            "subnets": subnet_ids,
            "assign_public_ip": False,
            "security_groups": security_groups
        },
        load_balancers=[{
            "target_group_arn": target_group.arn,
            "container_name": f"{resource_name}-container",
            "container_port": 80
        }]
    )

    return service